@@ -114,7 +114,7 @@ swap.web <- function(N, web, verbose=FALSE, c.crit=1e4){
     n <- sum(first>0)                         
     if (verbose) if (m > n) cat("Requires filling algorithm!\n") else cat("Requires emptying algorithm!\n")
     if (m < n) null <- downswap(first, m=m, n=n, c.crit=c.crit)
-    if (m >= n) null <- upswap(first, m=m, n=n)
+    if (m >= n) null <- upswap(first, m=m, n=n, c.crit=c.crit)
     null
   }
 
